@@ -3,11 +3,42 @@ import logging
 import os
 import sys
 from argparse import Namespace
+from dataclasses import dataclass
 from pathlib import Path
 
 from potodo import __version__
 
 
+@dataclass
+class Filters:
+    """Store the filtering argument of potodo."""
+
+    only_fuzzy: bool
+    exclude_fuzzy: bool
+    above: float
+    below: float
+    only_reserved: bool
+    exclude_reserved: bool
+
+
+def handle_dash_p_compat(args: argparse.Namespace) -> None:
+    """Could be removed in like 2028.
+
+    potodo had no position parameters, and I always forgot to type
+    `-p` to give a path. So now potodo accepts paths as positional
+    arguments :]
+    """
+
+    if args.old_paths:
+        print(
+            "🍰 hint: using -p to invoke potodo became optional in potodo 0.3.\n"
+            "         (and may be removed in the future)",
+            file=sys.stderr,
+        )
+    args.paths = args.old_paths + args.paths
+    del args.old_paths
+
+
 def parse_args() -> argparse.Namespace:
     parser = argparse.ArgumentParser(
         prog="potodo",
@@ -19,6 +50,16 @@ def parse_args() -> argparse.Namespace:
         "--path",
         help="execute Potodo in path",
         metavar="path",
+        action="append",
+        default=[],
+        dest="old_paths",
+    )
+
+    parser.add_argument(
+        "paths",
+        help="Examine files in given path(s)",
+        nargs="*",
+        metavar="path",
     )
 
     parser.add_argument(
@@ -30,6 +71,12 @@ def parse_args() -> argparse.Namespace:
         metavar="path",
     )
 
+    parser.add_argument(
+        "--no-color",
+        action="store_true",
+        help="Disable colored output.",
+    )
+
     parser.add_argument(
         "-a",
         "--above",
@@ -68,7 +115,11 @@ def parse_args() -> argparse.Namespace:
         "-u",
         "--api-url",
         help=(
-            "API URL to retrieve reservation tickets (https://api.github.com/repos/ORGANISATION/REPOSITORY/issues?state=open or https://git.afpy.org/api/v1/repos/ORGANISATION/REPOSITORY/issues?state=open&type=issues)"
+            "API URL to retrieve reservation tickets "
+            "(https://api.github.com/repos/ORGANISATION/REPOSITORY/issues?state=open "
+            "or "
+            "https://git.afpy.org/api/v1/repos/ORGANISATION/REPOSITORY/issues?"
+            "state=open&type=issues)"
         ),
     )
 
@@ -144,7 +195,8 @@ def parse_args() -> argparse.Namespace:
         "--matching-files",
         action="store_true",
         dest="matching_files",
-        help="Suppress normal output; instead print the name of each matching po file from which output would normally "
+        help="Suppress normal output; instead print the name of each matching po "
+        "file from which output would normally "
         "have been printed.",
     )
 
@@ -162,7 +214,17 @@ def parse_args() -> argparse.Namespace:
 
     # Initialize args and check consistency
     args = parser.parse_args()
+    handle_dash_p_compat(args)
     check_args(args)
+
+    args.filters = Filters(
+        above=args.above,
+        below=args.below,
+        exclude_fuzzy=args.exclude_fuzzy,
+        exclude_reserved=args.exclude_reserved,
+        only_reserved=args.only_reserved,
+        only_fuzzy=args.only_fuzzy,
+    )
     return args
 
 
@@ -183,7 +245,7 @@ def check_args(args: Namespace) -> None:
 
     if args.is_interactive:
         try:
-            import termios  # noqa
+            import termios  # pylint: disable=unused-import
         except ImportError:
             import platform
 
@@ -208,10 +270,10 @@ def check_args(args: Namespace) -> None:
         sys.exit(1)
 
     # If no path is specified, use current directory
-    if not args.path:
-        args.path = os.getcwd()
+    if not args.paths:
+        args.paths = [os.getcwd()]
 
-    args.path = Path(args.path).resolve()
+    args.paths = [Path(path).resolve() for path in args.paths]
 
     try:
         levels = [logging.CRITICAL, logging.WARNING, logging.INFO, logging.DEBUG]
