@@ -4,5 +4,5 @@ from typing import Optional
 
 def json_dateconv(o: object) -> Optional[str]:
     if isinstance(o, date):
-        return o.__str__()
+        return str(o)
     return None
